## What it is

Plugin which provides a notification mechanism to Salt, if Yum is
used outside of it.

## Installation

Configuration files are going to:

	`/etc/yum/pluginconf.d/[name].conf`

Plugin itself goes to:

	`/usr/share/yum-plugins/[name].conf`

## Permissions

User:  root
Group: root
Mode:  644
